Module window

Module window 

Build window-based GUI applications.

Modules

icon
Change the icon of a window.
screenshot
Take screenshots of a window.
settings
Configure your windows.

Structs

Icon
An window icon normally used for the titlebar or taskbar.
Id
The id of the window.
Screenshot
Data of a screenshot, captured with window::screenshot().
Settings
The window settings of an application.

Enums

Direction
The cardinal directions relative to the center of a window.
Event
A window-related event.
Level
A window level groups windows with respect to their z-position.
Mode
The mode of a window-based application.
Position
The position of a window in a given screen.
RedrawRequest
A request to redraw a window.
UserAttention
The type of user attention to request.